import { DatastoreOperations } from './datastore.methods';
import { GetOperation } from '../operations/get.operation';
import { PushOperation, BatchedPushOperation } from '../operations/push.operation';
import { Model } from '../model/model';
import { EditOperation } from '../operations/edit.operation';
import { DeleteOperation, BatchedDeleteOperation } from '../operations/delete.operation';
import { IEdit } from '../types/edit.types';
export interface DatastoreStreamIteratorData {
    key: string;
    value: any;
}
export interface PaginationData {
    skip: number;
    take: number;
}
export declare class Datastore<T extends Model<T>> {
    name: string;
    private store;
    private type;
    methods: DatastoreOperations<T>;
    constructor(name: string, directory: string, type: () => any, isValidated?: boolean);
    create(data: T): T;
    push(): PushOperation<T>;
    pushItem(item: T): Promise<T>;
    pushBatched(): BatchedPushOperation<T>;
    get(): GetOperation<T>;
    edit(): EditOperation<T>;
    editItem(item: string | T, edit: IEdit<T>): Promise<T>;
    delete(): DeleteOperation<T>;
    deleteItem(item: string | T): Promise<void>;
    deleteBatched(): BatchedDeleteOperation<T>;
    onPush(func: (data: T) => any): void;
    onEdit(func: (id: string, data: T) => any): void;
    onDelete(func: (id: string) => any): void;
}
