"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const levelup_1 = __importDefault(require("levelup"));
const leveldown_1 = __importDefault(require("leveldown"));
const encoding_down_1 = __importDefault(require("encoding-down"));
const path_1 = require("path");
const datastore_methods_1 = require("./datastore.methods");
const get_operation_1 = require("../operations/get.operation");
const push_operation_1 = require("../operations/push.operation");
const edit_operation_1 = require("../operations/edit.operation");
const delete_operation_1 = require("../operations/delete.operation");
class Datastore {
    constructor(name, directory, type, isValidated = false) {
        this.name = name;
        const encoding = encoding_down_1.default(leveldown_1.default(path_1.join(directory, name)), { valueEncoding: 'json' });
        this.store = levelup_1.default(encoding);
        this.type = type();
        this.methods = new datastore_methods_1.DatastoreOperations(() => this, this.store, type, isValidated);
    }
    create(data) {
        data.setDb(this);
        return data;
    }
    push() {
        return new push_operation_1.PushOperation(this);
    }
    pushItem(item) {
        return __awaiter(this, void 0, void 0, function* () {
            const result = yield this.push().item(item).run();
            return result;
        });
    }
    pushBatched() {
        return new push_operation_1.BatchedPushOperation(this);
    }
    get() {
        return new get_operation_1.GetOperation(this);
    }
    edit() {
        return new edit_operation_1.EditOperation(this);
    }
    editItem(item, edit) {
        return __awaiter(this, void 0, void 0, function* () {
            let result;
            if (typeof item === 'string') {
                result = yield this.edit().id(item).with(edit).run();
            }
            else {
                result = yield this.edit().item(item).with(edit).run();
            }
            return result;
        });
    }
    delete() {
        return new delete_operation_1.DeleteOperation(this);
    }
    deleteItem(item) {
        return __awaiter(this, void 0, void 0, function* () {
            if (typeof item === 'string') {
                yield this.delete().id(item).run();
            }
            else {
                yield this.delete().item(item).run();
            }
        });
    }
    deleteBatched() {
        return new delete_operation_1.BatchedDeleteOperation(this);
    }
    onPush(func) {
        this.methods.onPush(func);
    }
    onEdit(func) {
        this.methods.onEdit(func);
    }
    onDelete(func) {
        this.methods.onDelete(func);
    }
}
exports.Datastore = Datastore;
//# sourceMappingURL=datastore.js.map