import { LevelUp } from "levelup";
import EncodingDown from "encoding-down";
import { FilterOperator } from "../filter/filter";
import { PaginationData, Datastore } from "./datastore";
import { Model } from "../model/model";
import { ValueStream } from "./value.stream";
import { SortOperator } from "../..";
import { IObjectFields } from "../types/typings";
export declare class DatastoreOperations<T extends Model<T>> {
    private _store;
    store: LevelUp<EncodingDown<string, any>>;
    private type;
    private onDataPushed;
    private onDataEdited;
    private onDataDeleted;
    private isValidated;
    constructor(db: () => Datastore<T>, store: LevelUp<EncodingDown<string, any>>, type: () => any, isValidated?: boolean);
    private convertToPlain;
    private convertToClass;
    private convertToClassWithId;
    private setData;
    setPushData(id: string, item: T): void;
    setCreatedTime(item: T): void;
    setUpdatedTime(item: T): void;
    createReadStream(): ValueStream<T>;
    createReadStreamFiltered(filter?: FilterOperator<T>): ValueStream<T>;
    get(filter?: FilterOperator<T>): Promise<T[]>;
    getWithJustFields(filter?: FilterOperator<T>): Promise<IObjectFields<T>[]>;
    sort(items: T[], sort?: SortOperator<T>): T[];
    paginate(items: T[], pagination?: PaginationData): T[];
    count(filter?: FilterOperator<T>, pagination?: PaginationData): Promise<number>;
    getOne(id: string): Promise<T>;
    push(item: T): Promise<T>;
    put(id: string, item: T): Promise<T>;
    delete(id: string): Promise<void>;
    onPush(func: (data: T) => any): void;
    onEdit(func: (id: string, data: T) => any): void;
    onDelete(func: (id: string) => any): void;
}
