"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const class_transformer_1 = require("class-transformer");
const class_validator_1 = require("class-validator");
const nanoid_1 = __importDefault(require("nanoid"));
const moment = __importStar(require("moment"));
const value_stream_1 = require("./value.stream");
const utils_1 = require("../../utils");
class DatastoreOperations {
    constructor(db, store, type, isValidated = false) {
        this._store = db;
        this.store = store;
        this.isValidated = isValidated;
        this.type = type;
    }
    convertToPlain(item) {
        return class_transformer_1.classToPlain(item);
    }
    convertToClass(item) {
        return class_transformer_1.plainToClass(this.type(), item);
    }
    convertToClassWithId(item) {
        const converted = this.convertToClass(item);
        converted.setDb(this._store());
        return converted;
    }
    setData(item, id) {
        item.setData({ id, store: this._store() });
    }
    setPushData(id, item) {
        this.setData(item, id);
        this.setCreatedTime(item);
        this.setUpdatedTime(item);
    }
    setCreatedTime(item) {
        item.setCreatedTime(moment.now());
    }
    setUpdatedTime(item) {
        item.setUpdatedTime(moment.now());
    }
    createReadStream() {
        const stream = this.store.createValueStream();
        return new value_stream_1.ValueStream(stream);
    }
    createReadStreamFiltered(filter) {
        const stream = this.createReadStream();
        stream.middleware = (data) => {
            let pass = true;
            if (filter != null) {
                pass = filter.run(data);
            }
            return pass;
        };
        return stream;
    }
    get(filter) {
        return __awaiter(this, void 0, void 0, function* () {
            const results = [];
            const stream = this.createReadStreamFiltered(filter);
            stream.onData = (data) => {
                results.push(this.convertToClassWithId(data));
            };
            yield stream.untilEnd();
            return results;
        });
    }
    getWithJustFields(filter) {
        return __awaiter(this, void 0, void 0, function* () {
            const results = [];
            const stream = this.createReadStreamFiltered(filter);
            stream.onData = (data) => {
                results.push(data);
            };
            yield stream.untilEnd();
            return results;
        });
    }
    sort(items, sort) {
        if (!sort) {
            return items;
        }
        else {
            return sort.run(items);
        }
    }
    paginate(items, pagination) {
        if (!pagination) {
            return items;
        }
        else {
            return utils_1.Utils.paginate(items, pagination);
        }
    }
    count(filter, pagination) {
        return __awaiter(this, void 0, void 0, function* () {
            let count = 0;
            const stream = this.createReadStreamFiltered(filter);
            stream.onData = (data) => {
                count++;
            };
            yield stream.untilEnd();
            return count;
        });
    }
    getOne(id) {
        return __awaiter(this, void 0, void 0, function* () {
            const data = yield this.store.get(id);
            return this.convertToClassWithId(data);
        });
    }
    push(item) {
        return __awaiter(this, void 0, void 0, function* () {
            const id = nanoid_1.default();
            this.setPushData(id, item);
            const plain = this.convertToPlain(item);
            if (this.isValidated) {
                const errors = yield class_validator_1.validate(item);
                if (errors.length > 0) {
                    throw errors;
                }
            }
            yield this.store.put(id, plain);
            if (this.onDataPushed != null) {
                this.onDataPushed(item);
            }
            return item;
        });
    }
    put(id, item) {
        return __awaiter(this, void 0, void 0, function* () {
            this.setUpdatedTime(item);
            if (this.isValidated) {
                const errors = yield class_validator_1.validate(item);
                if (errors.length > 0) {
                    throw errors;
                }
            }
            yield this.store.put(id, this.convertToPlain(item));
            if (this.onDataEdited != null) {
                this.onDataEdited(id, item);
            }
            return item;
        });
    }
    delete(id) {
        return __awaiter(this, void 0, void 0, function* () {
            yield this.store.del(id);
            if (this.onDataDeleted != null) {
                this.onDataDeleted(id);
            }
        });
    }
    onPush(func) {
        this.onDataPushed = func;
    }
    onEdit(func) {
        this.onDataEdited = func;
    }
    onDelete(func) {
        this.onDataDeleted = func;
    }
}
exports.DatastoreOperations = DatastoreOperations;
//# sourceMappingURL=datastore.methods.js.map