"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
class DeleteOperation {
    constructor(store, id) {
        this._store = store;
        this._id = id;
    }
    item(item) {
        this._id = item.meta.id;
        return this;
    }
    id(id) {
        this._id = id;
        return this;
    }
    run() {
        return __awaiter(this, void 0, void 0, function* () {
            yield this.delete();
        });
    }
    delete() {
        return __awaiter(this, void 0, void 0, function* () {
            if (this._id == null) {
                throw new Error('Invalid parameters for DeleteOperation.');
            }
            yield this._store.methods.delete(this._id);
        });
    }
}
exports.DeleteOperation = DeleteOperation;
class BatchedDeleteOperation {
    constructor(store) {
        this._identifiers = [];
        this._store = store;
    }
    item(item) {
        this.id(item.meta.id);
        return this;
    }
    items(items) {
        items.forEach(item => this.item(item));
        return this;
    }
    id(id) {
        this._identifiers.push(id);
        return this;
    }
    ids(ids) {
        ids.forEach(id => this.id(id));
        return this;
    }
    identifiers(ids) {
        ids.forEach(id => this.id(id));
        return this;
    }
    run() {
        return __awaiter(this, void 0, void 0, function* () {
            yield this.delete();
        });
    }
    delete() {
        return __awaiter(this, void 0, void 0, function* () {
            const chain = this._store.methods.store.batch();
            for (const identifier of this._identifiers) {
                chain.del(identifier);
            }
            yield chain.write();
        });
    }
}
exports.BatchedDeleteOperation = BatchedDeleteOperation;
//# sourceMappingURL=delete.operation.js.map