"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const filter_1 = require("../filter/filter");
const sort_1 = require("../sort/sort");
class GetOperation {
    constructor(store) {
        this._filter = null;
        this._pagination = { skip: 0, take: Infinity };
        this._sort = null;
        this.store = store;
    }
    where(method) {
        return this.filter(method);
    }
    filter(method) {
        this._filter = new filter_1.FilterOperator(method);
        return this;
    }
    id(id) {
        this._filter = new filter_1.FilterOperator((v) => v.meta.id === id);
        return this;
    }
    orderBy(data) {
        return this.sort(data);
    }
    sort(data) {
        this._sort = new sort_1.SortOperator(data);
        return this;
    }
    paginate(data) {
        this._pagination = data;
        return this;
    }
    skip(skip) {
        this._pagination.skip = skip;
        return this;
    }
    take(take) {
        this._pagination.take = take;
        return this;
    }
    run() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.result();
        });
    }
    result() {
        return __awaiter(this, void 0, void 0, function* () {
            let result = yield this.store.methods.get(this._filter);
            result = this.store.methods.sort(result, this._sort);
            result = this.store.methods.paginate(result, this._pagination);
            return result;
        });
    }
    first() {
        return __awaiter(this, void 0, void 0, function* () {
            return (yield this.result())[0];
        });
    }
    last() {
        return __awaiter(this, void 0, void 0, function* () {
            const result = yield this.result();
            return (yield this.result())[result.length - 1];
        });
    }
    count() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.store.methods.count(this._filter, this._pagination);
        });
    }
}
exports.GetOperation = GetOperation;
//# sourceMappingURL=get.operation.js.map