"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const nanoid_1 = __importDefault(require("nanoid"));
const class_transformer_1 = require("class-transformer");
class PushOperation {
    constructor(store) {
        this._store = store;
    }
    item(value) {
        this._toAdd = value;
        return this;
    }
    run() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.push();
        });
    }
    push() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this._store.methods.push(this._toAdd);
        });
    }
}
exports.PushOperation = PushOperation;
class BatchedPushOperation {
    constructor(store) {
        this._toAdd = [];
        this._store = store;
    }
    item(value) {
        const id = nanoid_1.default();
        this._store.methods.setPushData(id, value);
        this._toAdd.push(value);
        return this;
    }
    items(values) {
        values.forEach(value => this.item(value));
        return this;
    }
    run() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.push();
        });
    }
    push() {
        return __awaiter(this, void 0, void 0, function* () {
            const chain = this._store.methods.store.batch();
            for (const value of this._toAdd) {
                chain.put(value.meta.id, class_transformer_1.classToPlain(value));
            }
            yield chain.write();
            return this._toAdd;
        });
    }
}
exports.BatchedPushOperation = BatchedPushOperation;
//# sourceMappingURL=push.operation.js.map