"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const index_test_config_1 = require("../../index.test.config");
const sort_types_1 = require("../sort/sort.types");
describe('GET operation', () => {
    describe('gets', () => {
        it('all elements', () => __awaiter(this, void 0, void 0, function* () {
            const data = yield index_test_config_1.testCreateRandomPlanets(true);
            const received = yield index_test_config_1.testStore.get().result();
            expect(received).toHaveLength(data.length);
        }));
        it('first element by sorting index', () => __awaiter(this, void 0, void 0, function* () {
            const data = yield index_test_config_1.testCreateRandomPlanets(true);
            const received = yield index_test_config_1.testStore.get()
                .sort({ index: { sort: sort_types_1.SortDirection.Ascending } })
                .first();
            expect(received).toEqual(data[0]);
        }));
        it('single element by filtering index', () => __awaiter(this, void 0, void 0, function* () {
            const index = 55;
            const data = yield index_test_config_1.testCreateRandomPlanets(true);
            const received = yield index_test_config_1.testStore.get()
                .filter((planet) => planet.index == index)
                .first();
            expect(received).toEqual(data[index]);
        }));
        it('five elements by filtering index', () => __awaiter(this, void 0, void 0, function* () {
            const data = yield index_test_config_1.testCreateRandomPlanets(true);
            const received = yield index_test_config_1.testStore.get()
                .filter((planet) => planet.index >= 0 && planet.index < 5)
                .sort({ index: { sort: sort_types_1.SortDirection.Ascending } })
                .result();
            const dataSplit = data.slice(0, 5);
            expect(received).toEqual(dataSplit);
        }));
        it('all elements by sorting index', () => __awaiter(this, void 0, void 0, function* () {
            const data = yield index_test_config_1.testCreateRandomPlanets(true);
            const received = yield index_test_config_1.testStore.get()
                .sort({ index: { sort: sort_types_1.SortDirection.Ascending } })
                .result();
            expect(received).toEqual(data);
        }));
        it('item by its id', () => __awaiter(this, void 0, void 0, function* () {
            const data = yield index_test_config_1.testCreateRandomPlanets(true);
            const firstPlanet = data[0];
            const received = yield index_test_config_1.testStore.get().id(firstPlanet.meta.id).first();
            expect(received).toEqual(firstPlanet);
        }));
    });
});
//# sourceMappingURL=get.operation.test.js.map